@@ -17,7 +17,7 @@
 #include <QApplication>
 #include <QTranslator>
 #include <QLocale>
-#include "mconfig.h"
+#include "mainwindow.h"
 #include <unistd.h>
 
 int main( int argc, char ** argv ) {
@@ -32,7 +32,7 @@ int main( int argc, char ** argv ) {
     app.installTranslator(&appTran);
 
     if (getuid() == 0) {
-        MConfig mw;
+        MainWindow mw;
         mw.show();
         return app.exec();
     } else {
